import './App.css';
import React, { useContext, useEffect, useState } from 'react';
import { BrowserRouter, Route, Switch } from 'react-router-dom';
import {useHttp} from '../src/zapros/hooks'
import {useAutorization} from '../src/zapros/autorization'
import AceEditor from "react-ace";
import { render } from "react-dom"
import "ace-builds/src-noconflict/mode-html";
import "ace-builds/src-noconflict/mode-css";
import "ace-builds/src-noconflict/mode-javascript";
import "ace-builds/src-noconflict/theme-terminal";
import "ace-builds/src-noconflict/ext-language_tools"
import { AuthorizationContext } from './context/autorizationCont';
// import 'brace/mode/javascript'; 
// import 'brace/theme/tomorrow_night';

const Login=()=>{
  const {loading, error, request}=useHttp()
  const [email,setEmail]=useState('')
  const [password,setPassword]=useState('')
  const [emailWrong, setEmailWrong]=useState(false)
  const [passwordWrong, setPasswordWrong]=useState(false)
  const [emailError,setEmailError]=useState('email empty')
  const [passwordError,setPasswordError]=useState('password empty')
  const [formValid,setFormValid]=useState(false)

  const emailHandler = (e)=>{
    setEmail(e.target.value)
    const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    if(!re.test(String(e.target.value).toLowerCase())){
      setEmailError('invalid login')
    }else{
      setEmailError("")
    }
  }

  const passwordHandler = (e)=>{
    setPassword(e.target.value)
    if(e.target.value.length<=3){
      setPasswordError('password must be longer than 6 characters')
    }else{
      setPasswordError('')
    }
  }

  useEffect(()=>{
    if(emailError || passwordError){
      setFormValid(false)
    }else{
      setFormValid(true)
    }
  })


  const outInput = (e) =>{
    switch(e.target.name){
      case 'email':
        setEmailWrong(true)
      break;
      case 'password' : 
        setPasswordWrong(true)
      break;
    }
  }
  const log = async ()=>{
    try{
      const data = await request('/api/authorization/login','POST',[email,password])
      console.log('Data',data)
    }catch(e){
        console.log(e)
    }
  }

  return(
    <fieldset className="logForm">
      <legend className="lr_title">Login</legend>
      <form className="login">

        <fieldset>
          <legend>Email</legend>
          <input onChange={e => emailHandler(e)} value={email} onBlur={e=>outInput(e)} name='email' className='email' type="text" placeholder='Enter you email...'/>
        </fieldset>
        <fieldset>
          <legend>Password</legend>
          <input onChange={e => passwordHandler(e)} value={password} onBlur={e=>outInput(e)} name='password' className='password' type="password" placeholder='Enter you password...'/>
        </fieldset>
        <button disabled={!formValid} className='submitLR' type='button' onClick={log}>Login</button>
        {(emailWrong&&emailError)&& <p style={{color:'orange'}}>{emailError}</p>}
        {(passwordWrong&&passwordError) && <p style={{color:'orange'}}>{passwordError}</p>}
      </form>
      <a href="/registration" className="legend2">Registration</a>
    </fieldset>
  )
}

const Registration=()=>{
  const [email,setEmail]=useState('')
  const [password,setPassword]=useState('')
  const [emailWrong, setEmailWrong]=useState(false)
  const [passwordWrong, setPasswordWrong]=useState(false)
  const [emailError,setEmailError]=useState('email empty')
  const [passwordError,setPasswordError]=useState('password empty')
  const [formValid,setFormValid]=useState(false)
  const {loading, error, request}=useHttp()
  const registerHandler = async () => {
    try {
      const data = await request('/api/authorization/registration', 'POST', {email,password})
      // auth.logIn(data.token,data.userId)
    } catch (e) {}
  }
  // const auth = useContext(AuthorizationContext)
  const emailHandler = (e)=>{
    setEmail(e.target.value)
    const re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
    if(!re.test(String(e.target.value).toLowerCase())){
      setEmailError('invalid login')
    }else{
      setEmailError("")
    }
  }

  const passwordHandler = (e)=>{
    setPassword(e.target.value)
    if(e.target.value.length<=3){
      setPasswordError('password must be longer than 6 characters')
    }else{
      setPasswordError('')
    }
  }

  useEffect(()=>{
    if(emailError || passwordError){
      setFormValid(false)
    }else{
      setFormValid(true)
    }
  })


  const outInput = (e) =>{
    switch(e.target.name){
      case 'email':
        setEmailWrong(true)
      break;
      case 'password' : 
        setPasswordWrong(true)
      break;
    }
  }
  return(
    <fieldset className="logForm">
      <legend className="lr_title">Registration</legend>
      <form className="login">
        <fieldset>
          <legend>Email</legend>
          <input onChange={e => emailHandler(e)} value={email} onBlur={e=>outInput(e)} name='email' className='email' type="text" placeholder='Enter you email...'/>
        </fieldset>
        <fieldset>
          <legend>Password</legend>
          <input onChange={e => passwordHandler(e)}value={password} onBlur={e=>outInput(e)} name='password' className='password'  type="password" placeholder='Enter you password...'/>
        </fieldset>
        <button disabled={!formValid} className='submitLR' type='button' onClick={registerHandler}>Registration</button>
        {(emailWrong&&emailError)&& <p style={{color:'orange'}}>{emailError}</p>}
        {(passwordWrong&&passwordError) && <p style={{color:'orange'}}>{passwordError}</p>}
      </form>
      <a href="/" className="legend2">Login</a>
    </fieldset>
  )
}

const NavBar=()=>{

  return(
    <div className="navBar">
      <h1 className="logo"><a href="/">SandBox</a></h1>
      <a href="/Project" className="links">Project</a>
      <a href="/my_project" className="links">My project</a>
      <a href="/sandbox" className="links">Sandbox</a>
    </div>
  )
}



const SandBox =()=>{
  const {loading, error, request}=useHttp()
  let userID
  let title="code red"
  let codeHTML = "<div id='good_code'>\n    <h1>Hellow</h1>\n</div>"
  let codeCSS='h1,h2{\n    collor:yellow;\n}'
  let codeJS='var el = document.getElementById("good_code");\nel.innetHTML = "<h2>word</h2>"'


  const saveProject = async () => {
    try {
      const data = await request('/api/save', 'POST', {userID,title,codeHTML,codeCSS,codeJS})
    } catch (e) {}
  }
  
  return(
    <div>
      <fieldset className="title">
        <legend>Title</legend>
        <textarea className="nameProj" name="title">{title}</textarea>
        <button>generate</button>
        <button className='saveProject' type='button' onClick={saveProject} >save</button>
      </fieldset>
       <form className="ide">
        <fieldset className="dev">
          <legend>codeHTML</legend>
          <AceEditor className="windDev" placeholder="textarea" mode="html" value={codeHTML} theme="terminal" name="blah2"  fontSize={14} showPrintMargin={true} showGutter={true} highlightActiveLine={true} setOptions={{ enableBasicAutocompletion: true, enableLiveAutocompletion: true, enableSnippets: true, showLineNumbers: true,tabSize: 2,}} style={{height:"380px"}}/>,
        </fieldset>
        <fieldset className="dev">
          <legend>codeCSS</legend>
          <AceEditor className="windDev" placeholder="textarea" mode="css" value={codeCSS} theme="terminal" name="blah2"  fontSize={14} showPrintMargin={true} showGutter={true} highlightActiveLine={true} setOptions={{ enableBasicAutocompletion: true, enableLiveAutocompletion: true, enableSnippets: true, showLineNumbers: true,tabSize: 2,}} style={{height:"380px"}}/>,
        </fieldset><fieldset className="dev">
          <legend>codeJS</legend>
          <AceEditor className="windDev" placeholder="textarea" mode="javascript" theme="terminal" name="blah2"  fontSize={14} showPrintMargin={true} showGutter={true} highlightActiveLine={true} value={codeJS} setOptions={{ enableBasicAutocompletion: true, enableLiveAutocompletion: true, enableSnippets: true, showLineNumbers: true,tabSize: 2,}} style={{height:"380px"}}/>,
        </fieldset>    
      </form>
      <fieldset className="oput">
      <legend>outPut</legend>
      <div className="output" name="output" contentEditable='true' dangerouslySetInnerHTML={{ __html: codeHTML }} > 

      </div>
      </fieldset>
    </div>
  )
}
const MyProject=()=>{
  return(
    <fieldset className="project">
        <legend>My Project</legend>
        <ul className="myProject">
          <li className="creatorProject"><a href="/sandbox">++++++++++CREATE+A+NEW+PROJECT++++++++++</a></li>
        </ul>
    </fieldset>
  )
}
const Project=()=>{
  return(
    <fieldset className="project">
        <legend>Project</legend>
        <ul className="worldProject">
          <li className="creatorProject"><a href="/sandbox">++++++++++CREATE+A+NEW+PROJECT++++++++++</a></li>
        </ul>
    </fieldset>
  )
}


// const {token, logIn , logOut , userId} = useAutorization
// const isAuthenticated = !!token

const App =()=>
      <BrowserRouter>
        <NavBar/>
        <Switch>
          <Route path='/' component={Login} exact/>
          <Route path='/registration' component={Registration}/>
          <Route path="/sandbox" component={SandBox}/>
          <Route path="/my_project" component={MyProject}/>
          <Route path="/project" component={Project}/>
        </Switch>
      </BrowserRouter>
  // <AuthorizationContext.Provider value={token, logIn , logOut , userId,isAuthenticated}>
  // </AuthorizationContext.Provider>

export default App;
